@@ -11,7 +11,7 @@ from tqdm.auto import tqdm
 
 from .file import RDYFile
 from .osm import OSMRegion, OSMRailwaySwitch, OSMRailwaySignal, OSMLevelCrossing
-from .osm.utils import calc_perpendicular_distance, is_point_within_line_projection
+from .osm.utils import project_point_onto_line, is_point_within_line_projection
 from .utils import GPSSeries
 from .utils.tools import generate_random_color
 
@@ -186,10 +186,14 @@ class Campaign:
 
                 start_message = HTML()
                 end_message = HTML()
-                start_message.value = "<p>Start:</p><p>" + f.name + "</p><p>" + f.device.manufacturer + "; " \
-                                      + f.device.model + "</p>"
-                end_message.value = "<p>End:</p><p>" + f.name + "</p><p>" + f.device.manufacturer + "; " \
-                                    + f.device.model + "</p>"
+                start_message.value = "<p>Start:</p><p>" \
+                                      + str(f.name or '') + "</p><p>" \
+                                      + str(f.device.manufacturer) + "; " \
+                                      + str(f.device.model) + "</p>"
+                end_message.value = "<p>End:</p><p>" \
+                                    + str(f.name or '') + "</p><p>" \
+                                    + str(f.device.manufacturer or '') + "; " \
+                                    + str(f.device.model or '') + "</p>"
 
                 start_marker.popup = start_message
                 end_marker.popup = end_message
@@ -218,7 +222,7 @@ class Campaign:
                 file_polyline = Polyline(locations=coords, color=line.color, fill=False, weight=4)
                 m.add_layer(file_polyline)
         else:
-            logger.warning("No OSM region downloaded!")
+            logger.info("No OSM region downloaded!")
 
         return m
 
@@ -362,7 +366,7 @@ class Campaign:
                         for p1, p2 in zip(track_xy, track_xy[1:]):
                             if not np.array_equal(p1, p2):
                                 el_x, el_y = proj(el.lon, el.lat)
-                                d = calc_perpendicular_distance(np.array([p1, p2]), np.array([el_x, el_y]))
+                                d = project_point_onto_line(np.array([p1, p2]), np.array([el_x, el_y]))
                                 b = is_point_within_line_projection(np.array([p1, p2]), np.array([el_x, el_y]))
                                 if b and d <= d_min:
                                     mask[i] = True
