@@ -281,13 +281,14 @@ class RDYFile:
             start_message = HTML()
             end_message = HTML()
             start_message.value = "<p>Start:</p><p>" + self.name + "</p><p>" \
-                                  + str(time[0]) + "</p><p>"\
-                                  + self.device.manufacturer + "; " \
-                                  + self.device.model + "</p>"
+                                  + str(time[0] or 'n/a') + "</p><p>" \
+                                  + str(self.device.manufacturer or 'n/a') + "; " \
+                                  + str(self.device.model or 'n/a') + "</p>"
+
             end_message.value = "<p>End:</p><p>" + self.name + "</p><p>" \
-                                + str(time[-1]) + "</p><p>" \
-                                + self.device.manufacturer + "; " \
-                                + self.device.model + "</p>"
+                                + str(time[-1] or 'n/a') + "</p><p>" \
+                                + str(self.device.manufacturer or 'n/a') + "; " \
+                                + str(self.device.model or 'n/a') + "</p>"
 
             start_marker.popup = start_message
             end_marker.popup = end_message
@@ -302,7 +303,7 @@ class RDYFile:
                     circle.radius = int(h)
                     circle.color = "#00549F"
                     circle.fill_color = "#00549F"
-                    circle.stroke = 3
+                    circle.weight = 3
                     circle.fill_opacity = 0.1
 
                     m.add_layer(circle)
@@ -863,9 +864,14 @@ class RDYFile:
         else:
             raise ValueError("File extension %s is not supported" % self.extension)
 
-    def to_df(self) -> pd.DataFrame:
+    def to_df(self, interpolate: bool = True) -> pd.DataFrame:
         """ Merges the measurement series to a single DataFrame
 
+        Parameters
+        ----------
+            interpolate : bool
+                If true interpolates NaN values of concatenated measurement series
+
         Returns
         -------
             pd.DataFrame
@@ -876,7 +882,10 @@ class RDYFile:
         df_merged = pd.concat(data_frames).sort_index()
 
         # Merge identical indices by taking mean of column values and then interpolate NaN values
-        df_merged = df_merged.groupby(level=0).mean().interpolate()
+        if interpolate:
+            df_merged = df_merged.groupby(level=0).mean().interpolate()
+        else:
+            df_merged = df_merged.groupby(level=0).mean()
         return df_merged
 
 
