@@ -14,7 +14,20 @@ class Device:
                  model: Union[str, Series] = None,
                  gnss_hardware_model_name: Union[str, Series] = None,
                  gnss_year_of_hardware: Union[int, Series] = None):
+        """ Class representing Android device information
 
+        Parameters
+        ----------
+        api_level
+        base_os
+        brand
+        manufacturer
+        device
+        product
+        model
+        gnss_hardware_model_name
+        gnss_year_of_hardware
+        """
         if type(api_level) == Series:
             self.api_level = api_level[0] if len(api_level) > 0 else None
         else:
@@ -62,7 +75,7 @@ class Device:
 
     def __repr__(self):
         return "Brand: %s, Model: %s, Product: %s, Device: %s, Manufacturer: %s, Base OS: %s, API Level: %d, " \
-               "GNSS Hardware Model Name: %s, GNSS Year of Hardware" \
+               "GNSS Hardware Model Name: %s, GNSS Year of Hardware %d" \
                % (self.brand, self.model, self.product, self.device, self.manufacturer, self.base_os,
                   self.api_level if self.api_level else -1, self.gnss_hardware_model_name,
                   self.gnss_year_of_hardware if self.gnss_year_of_hardware else -1)
